use-robot
Primitive robot vocabulary for RustUse.
This crate provides descriptive robot names, kinds, models, and manufacturers. It does not create robot registries, connect to robots, control robots, or implement robot configuration systems.
Example
use use_robot::{RobotKind, RobotModel, RobotName};
let name = RobotName::new("inspection-arm")?;
let model = RobotModel::new("RX-4")?;
let kind = "collaborative".parse::<RobotKind>()?;
assert_eq!(name.as_str(), "inspection-arm");
assert_eq!(model.as_str(), "RX-4");
assert_eq!(kind.to_string(), "collaborative");License
Licensed under either the MIT license or Apache License, Version 2.0. Primitive robot vocabulary.
Structs
- Robot
Manufacturer - A descriptive robot manufacturer label.
- Robot
Model - A non-empty robot model label.
- Robot
Name - A non-empty robot name.
Enums
- Robot
Kind - Broad robot vocabulary.
- Robot
Kind Parse Error - Error returned when parsing robot kinds fails.
- Robot
Text Error - Errors returned while constructing robot text values.